Dad & Dave's Brewing - Brookvale, NSW - Beer Menu on Untappd
Author: The Untappd Team
Description: See what's currently available on Dad & Dave's Brewing's beer menu in Brookvale, NSW in real-time. See activity, upcoming events, photos and more
Keywords: See what's currently available on Dad & Dave's Brewing's beer menu in Brookvale, NSW in real-time. See activity, upcoming events, photos and more

Verified

# Dad & Dave's Brewing

## Brewery, Beer Bar, Burger Joint, Distillery

45 Mitchell Rd Brookvale, NSW ( Map )

+61 452 661 839

Foursquare www.dadndavesbrewing.com

Foursquare

45 Mitchell Rd Brookvale, NSW (Map)

+61 452 661 839

www.dadndavesbrewing.com

{"count":7,"items":[{"day_name":"Monday","is_24":0,"is_open":0,"hours":[]},{"day_name":"Tuesday","is_24":0,"is_open":0,"hours":[]},{"day_name":"Wednesday","is_24":0,"is_open":0,"hours":[]},{"day_name":"Thursday","is_24":0,"is_open":1,"hours":[{"start_time":"17:00:00","end_time":"22:00:00"}]},{"day_name":"Friday","is_24":0,"is_open":1,"hours":[{"start_time":"16:00:00","end_time":"22:00:00"}]},{"day_name":"Saturday","is_24":0,"is_open":1,"hours":[{"start_time":"12:00:00","end_time":"22:00:00"}]},{"day_name":"Sunday","is_24":0,"is_open":1,"hours":[{"start_time":"12:00:00","end_time":"18:00:00"}]}]}

### Receive Venue Notifications

Receive alerts via Untappd on your mobile device when this venue adds new beers and/or events!

Choose notifications

An error occured. Please try again.

Great! Your subscription to this venue was successful.

### Hours

- Monday

  Closed

- Tuesday

  Closed

- Wednesday

  Closed

- Thursday

  5PM - 10PM

- Friday

  4PM - 10PM

- Saturday

  12PM - 10PM

- Sunday

  12PM - 6PM

### Details

- Payment Types: Google Pay, Samsung Pay, Apple Pay, Visa, Master Card, American Express
- Food Served
- Growlers
- Kegs
- Wine
- Cocktails
- Outdoor Seating
- Pet Friendly
- Child Friendly

### Social

Foursquare

### Venue Stats (?)

- 2,656 Total
- 564 Unique
- 9 Monthly
- 0 You

### Loyal Patrons (?)

More Venue Details

### Photos

See More Photos

### Recent Activity

- Sun, 02 Mar 2025 06:11:56 +0000

  #### Patrick Koole

  ##### Hazy

  ##### Dad & Dave's Brewing

- Sat, 01 Mar 2025 07:45:04 +0000

  #### Danny Lemos

  ##### Dad's Pils

  ##### Dad & Dave's Brewing

- Sat, 01 Mar 2025 07:39:29 +0000

  #### Chris Donn

  ##### Yuzu Sour

  ##### Dad & Dave's Brewing

- Sun, 23 Feb 2025 05:38:01 +0000

  #### Ben Beers

  ##### Mountain XPA

  ##### Dad & Dave's Brewing

- Sun, 23 Feb 2025 05:20:00 +0000

  #### Wardy

  ##### Citra & Mosaic IPA

  ##### Dad & Dave's Brewing

See All Activity

See Latest Activity

### All Menus

Loading...
Show More